window.Gleam.initSearch([{"doc":"bigi","title":"bigi","content":"# bigi\n\n[![Package Version](https://img.shields.io/hexpm/v/bigi)](https://hex.pm/packages/bigi)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bigi/)\n\nArbitrary precision integer arithmetic for Gleam.\n\nIn the Erlang target, all integers are automatically &quot;big integers&quot; that are subject to\narbitrary precision arithmetic. This means there is no need for this package if you are only\ntargeting Erlang.\n\nIn JavaScript, Gleam&#39;s `Int` type corresponds to the `number` type, which is implemented using\nfloating-point arithmetic. That means it&#39;s subject to the following limits:\n\n- [Maximum safe integer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER)\n  and\n  [minimum safe integer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MIN_SAFE_INTEGER)\n  beyond which the accuracy of arithmetic suffers, and\n- [maximum value](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_VALUE)\n  and\n  [minimum value](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MIN_VALUE)\n  beyond which the numbers are converted to `Infinity` or `-Infinity`.\n\nThis package thus provides big integers for the JavaScript target and additionally provides a\nconsistent interface for packages that target both Erlang and JavaScript. In Erlang, regular\nintegers are used. In JavaScript, the\n[`BigInt`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/BigInt)\ntype is used.\n\n```sh\ngleam add bigi\n```\n\n```gleam\nimport bigi\n\npub fn main() {\n  bigi.power(\n    bigi.from_int(2),\n    bigi.from_int(65_535)\n  )\n\n  // Ok(1001764965203423232489536175780127875223912737784875709632508486855447029778...)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bigi&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"bigi","title":"BigInt","content":"pub type BigInt\n A big integer.\n\nSynonyms:\nbigi.BigInt\nbigi BigInt","url":"bigi.html#BigInt"},{"doc":"bigi","title":"absolute","content":"pub fn absolute(bigint: BigInt) -&gt; BigInt\n Get the absolute value of a big integer.\nSynonyms:\nbigi.absolute\nbigi absolute","url":"bigi.html#absolute"},{"doc":"bigi","title":"add","content":"pub fn add(a: BigInt, b: BigInt) -&gt; BigInt\n Add two big integers together.\nSynonyms:\nbigi.add\nbigi add","url":"bigi.html#add"},{"doc":"bigi","title":"compare","content":"pub fn compare(a: BigInt, with b: BigInt) -&gt; Order\n Compare two big integers, returning an order that denotes if `a` is lower,\n bigger than, or equal to `b`.\nSynonyms:\nbigi.compare\nbigi compare","url":"bigi.html#compare"},{"doc":"bigi","title":"decode","content":"pub fn decode(dyn: Dynamic) -&gt; Result(BigInt, List(DecodeError))\n Decode a `gleam/dynamic` value into a big integer, if possible.\nSynonyms:\nbigi.decode\nbigi decode","url":"bigi.html#decode"},{"doc":"bigi","title":"digits","content":"pub fn digits(bigint: BigInt) -&gt; List(Int)\n Get the digits in a given bigint as a list of integers.\n\n The list is ordered starting from the most significant digit.\nSynonyms:\nbigi.digits\nbigi digits","url":"bigi.html#digits"},{"doc":"bigi","title":"divide","content":"pub fn divide(dividend a: BigInt, divisor b: BigInt) -&gt; BigInt\n Divide the dividend with the divisor using integer division.\n\n Follows the standard Gleam divide-by-zero rule of 0 when the divisor is 0.\nSynonyms:\nbigi.divide\nbigi divide","url":"bigi.html#divide"},{"doc":"bigi","title":"divide_no_zero","content":"pub fn divide_no_zero(\n  dividend a: BigInt,\n  divisor b: BigInt,\n) -&gt; Result(BigInt, Nil)\n Divide the dividend with the divisor using integer division.\n\n Returns an error if the divisor is 0.\nSynonyms:\nbigi.divide_no_zero\nbigi divide_no_zero","url":"bigi.html#divide_no_zero"},{"doc":"bigi","title":"from_int","content":"pub fn from_int(int: Int) -&gt; BigInt\n Create a big integer from a regular integer.\n\n Note that in the JavaScript target, if your integer is bigger than the\n [maximum safe integer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER)\n or smaller than the\n [minimum safe integer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MIN_SAFE_INTEGER),\n you may lose precision when operating on it, including when converting it\n into a big integer (as the JavaScript Number type has already reduced the\n precision of the value).\nSynonyms:\nbigi.from_int\nbigi from_int","url":"bigi.html#from_int"},{"doc":"bigi","title":"from_string","content":"pub fn from_string(str: String) -&gt; Result(BigInt, Nil)\n Convert a string into a big integer.\n\n If the string does not represent a big integer in base 10, an error is\n returned. Trailing non-digit content is not allowed.\nSynonyms:\nbigi.from_string\nbigi from_string","url":"bigi.html#from_string"},{"doc":"bigi","title":"modulo","content":"pub fn modulo(dividend a: BigInt, divisor b: BigInt) -&gt; BigInt\n Calculate a mathematical modulo operation.\n\n Follows the standard Gleam divide-by-zero rule of 0 when the divisor is 0.\nSynonyms:\nbigi.modulo\nbigi modulo","url":"bigi.html#modulo"},{"doc":"bigi","title":"modulo_no_zero","content":"pub fn modulo_no_zero(\n  dividend a: BigInt,\n  divisor b: BigInt,\n) -&gt; Result(BigInt, Nil)\n Calculate a mathematical modulo operation.\n\n Returns an error if the divisor is 0.\nSynonyms:\nbigi.modulo_no_zero\nbigi modulo_no_zero","url":"bigi.html#modulo_no_zero"},{"doc":"bigi","title":"multiply","content":"pub fn multiply(a: BigInt, b: BigInt) -&gt; BigInt\n Multiply two big integers together.\nSynonyms:\nbigi.multiply\nbigi multiply","url":"bigi.html#multiply"},{"doc":"bigi","title":"power","content":"pub fn power(\n  base a: BigInt,\n  exponent b: BigInt,\n) -&gt; Result(BigInt, Nil)\n Raise the base to the exponent.\n\n If the exponent is negative, an error is returned.\nSynonyms:\nbigi.power\nbigi power","url":"bigi.html#power"},{"doc":"bigi","title":"remainder","content":"pub fn remainder(dividend a: BigInt, divisor b: BigInt) -&gt; BigInt\n Divide the dividend with the divisor using integer division and return the\n remainder.\n\n Follows the standard Gleam divide-by-zero rule of 0 when the divisor is 0.\nSynonyms:\nbigi.remainder\nbigi remainder","url":"bigi.html#remainder"},{"doc":"bigi","title":"remainder_no_zero","content":"pub fn remainder_no_zero(\n  dividend a: BigInt,\n  divisor b: BigInt,\n) -&gt; Result(BigInt, Nil)\n Divide the dividend with the divisor using integer division and return the\n remainder.\n\n Returns an error if the divisor is 0.\nSynonyms:\nbigi.remainder_no_zero\nbigi remainder_no_zero","url":"bigi.html#remainder_no_zero"},{"doc":"bigi","title":"subtract","content":"pub fn subtract(\n  minuend a: BigInt,\n  subtrahend b: BigInt,\n) -&gt; BigInt\n Subtract the subtrahend from the minuend.\nSynonyms:\nbigi.subtract\nbigi subtract","url":"bigi.html#subtract"},{"doc":"bigi","title":"to_int","content":"pub fn to_int(bigint: BigInt) -&gt; Result(Int, Nil)\n Convert a big integer to a regular integer.\n\n In Erlang, this cannot fail, as all Erlang integers are big integers. In the\n JavaScript target, this will fail if the integer is bigger than the\n [maximum safe integer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER)\n or smaller than the\n [minimum safe integer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MIN_SAFE_INTEGER).\nSynonyms:\nbigi.to_int\nbigi to_int","url":"bigi.html#to_int"},{"doc":"bigi","title":"to_string","content":"pub fn to_string(bigint: BigInt) -&gt; String\n Convert the big integer into a simple string - a sequence of digits.\nSynonyms:\nbigi.to_string\nbigi to_string","url":"bigi.html#to_string"},{"doc":"bigi","title":"zero","content":"pub fn zero() -&gt; BigInt\n Create a big integer representing zero.\nSynonyms:\nbigi.zero\nbigi zero","url":"bigi.html#zero"},{"doc":"bigi","title":"bigi","content":"","url":"bigi.html"}]);